@@ -34,91 +34,97 @@ const (
 	AllocSpecPage
 	LogsPage
 	LoglinePage
+	StatsPage
 )
 
-func GetAllPageConfigs(width, height int, copySavePath, compactTables bool) map[Page]page.Config {
+func GetAllPageConfigs(width, height int, compactTables bool) map[Page]page.Config {
 	return map[Page]page.Config{
 		JobsPage: {
 			Width: width, Height: height,
-			LoadingString: JobsPage.LoadingString(),
-			CopySavePath:  copySavePath, SelectionEnabled: true, WrapText: false, RequestInput: false,
+			LoadingString:    JobsPage.LoadingString(),
+			SelectionEnabled: true, WrapText: false, RequestInput: false,
 			CompactTableContent:      compactTables,
 			ViewportConditionalStyle: constants.JobsTableStatusStyles,
 		},
 		AllTasksPage: {
 			Width: width, Height: height,
-			LoadingString: AllTasksPage.LoadingString(),
-			CopySavePath:  copySavePath, SelectionEnabled: true, WrapText: false, RequestInput: false,
+			LoadingString:    AllTasksPage.LoadingString(),
+			SelectionEnabled: true, WrapText: false, RequestInput: false,
 			CompactTableContent:      compactTables,
 			ViewportConditionalStyle: constants.TasksTableStatusStyles,
 		},
 		JobSpecPage: {
 			Width: width, Height: height,
-			LoadingString: JobSpecPage.LoadingString(),
-			CopySavePath:  copySavePath, SelectionEnabled: false, WrapText: true, RequestInput: false,
+			LoadingString:    JobSpecPage.LoadingString(),
+			SelectionEnabled: false, WrapText: true, RequestInput: false,
 		},
 		JobEventsPage: {
 			Width: width, Height: height,
-			LoadingString: JobEventsPage.LoadingString(),
-			CopySavePath:  copySavePath, SelectionEnabled: true, WrapText: false, RequestInput: false,
+			LoadingString:    JobEventsPage.LoadingString(),
+			SelectionEnabled: true, WrapText: false, RequestInput: false,
 		},
 		JobEventPage: {
 			Width: width, Height: height,
-			LoadingString: JobEventPage.LoadingString(),
-			CopySavePath:  copySavePath, SelectionEnabled: false, WrapText: true, RequestInput: false,
+			LoadingString:    JobEventPage.LoadingString(),
+			SelectionEnabled: false, WrapText: true, RequestInput: false,
 		},
 		JobMetaPage: {
 			Width: width, Height: height,
-			LoadingString: JobMetaPage.LoadingString(),
-			CopySavePath:  copySavePath, SelectionEnabled: false, WrapText: true, RequestInput: false,
+			LoadingString:    JobMetaPage.LoadingString(),
+			SelectionEnabled: false, WrapText: true, RequestInput: false,
 			CompactTableContent: compactTables,
 		},
 		AllocEventsPage: {
 			Width: width, Height: height,
-			LoadingString: AllocEventsPage.LoadingString(),
-			CopySavePath:  copySavePath, SelectionEnabled: true, WrapText: false, RequestInput: false,
+			LoadingString:    AllocEventsPage.LoadingString(),
+			SelectionEnabled: true, WrapText: false, RequestInput: false,
 		},
 		AllocEventPage: {
 			Width: width, Height: height,
-			LoadingString: AllocEventPage.LoadingString(),
-			CopySavePath:  copySavePath, SelectionEnabled: false, WrapText: true, RequestInput: false,
+			LoadingString:    AllocEventPage.LoadingString(),
+			SelectionEnabled: false, WrapText: true, RequestInput: false,
 		},
 		AllEventsPage: {
 			Width: width, Height: height,
-			LoadingString: AllEventsPage.LoadingString(),
-			CopySavePath:  copySavePath, SelectionEnabled: true, WrapText: false, RequestInput: false,
+			LoadingString:    AllEventsPage.LoadingString(),
+			SelectionEnabled: true, WrapText: false, RequestInput: false,
 		},
 		AllEventPage: {
 			Width: width, Height: height,
-			LoadingString: AllEventPage.LoadingString(),
-			CopySavePath:  copySavePath, SelectionEnabled: false, WrapText: true, RequestInput: false,
+			LoadingString:    AllEventPage.LoadingString(),
+			SelectionEnabled: false, WrapText: true, RequestInput: false,
 		},
 		JobTasksPage: {
 			Width: width, Height: height,
-			LoadingString: JobTasksPage.LoadingString(),
-			CopySavePath:  copySavePath, SelectionEnabled: true, WrapText: false, RequestInput: false,
+			LoadingString:    JobTasksPage.LoadingString(),
+			SelectionEnabled: true, WrapText: false, RequestInput: false,
 			CompactTableContent:      compactTables,
 			ViewportConditionalStyle: constants.TasksTableStatusStyles,
 		},
 		ExecPage: {
 			Width: width, Height: height,
-			LoadingString: ExecPage.LoadingString(),
-			CopySavePath:  copySavePath, SelectionEnabled: false, WrapText: true, RequestInput: true,
+			LoadingString:    ExecPage.LoadingString(),
+			SelectionEnabled: false, WrapText: true, RequestInput: true,
 		},
 		AllocSpecPage: {
 			Width: width, Height: height,
-			LoadingString: AllocSpecPage.LoadingString(),
-			CopySavePath:  copySavePath, SelectionEnabled: false, WrapText: true, RequestInput: false,
+			LoadingString:    AllocSpecPage.LoadingString(),
+			SelectionEnabled: false, WrapText: true, RequestInput: false,
 		},
 		LogsPage: {
 			Width: width, Height: height,
-			LoadingString: LogsPage.LoadingString(),
-			CopySavePath:  copySavePath, SelectionEnabled: true, WrapText: false, RequestInput: false,
+			LoadingString:    LogsPage.LoadingString(),
+			SelectionEnabled: true, WrapText: false, RequestInput: false,
 		},
 		LoglinePage: {
 			Width: width, Height: height,
-			LoadingString: LoglinePage.LoadingString(),
-			CopySavePath:  copySavePath, SelectionEnabled: false, WrapText: true, RequestInput: false,
+			LoadingString:    LoglinePage.LoadingString(),
+			SelectionEnabled: false, WrapText: true, RequestInput: false,
+		},
+		StatsPage: {
+			Width: width, Height: height,
+			LoadingString:    StatsPage.LoadingString(),
+			SelectionEnabled: false, WrapText: false, RequestInput: false,
 		},
 	}
 }
@@ -153,7 +159,7 @@ func (p Page) ShowsTasks() bool {
 	return false
 }
 
-func (p Page) CanBeStart() bool {
+func (p Page) CanBeFirstPage() bool {
 	return p == JobsPage || p == AllTasksPage
 }
 
@@ -209,6 +215,8 @@ func (p Page) String() string {
 		return "logs"
 	case LoglinePage:
 		return "log"
+	case StatsPage:
+		return "stats"
 	}
 	return "unknown"
 }
@@ -237,7 +245,7 @@ func (p Page) Forward() Page {
 	return p
 }
 
-func returnToPage(inJobsMode bool) Page {
+func returnToTasksPage(inJobsMode bool) Page {
 	if inJobsMode {
 		return JobTasksPage
 	}
@@ -255,7 +263,7 @@ func (p Page) Backward(inJobsMode bool) Page {
 	case JobMetaPage:
 		return JobsPage
 	case AllocEventsPage:
-		return returnToPage(inJobsMode)
+		return returnToTasksPage(inJobsMode)
 	case AllocEventPage:
 		return AllocEventsPage
 	case AllEventsPage:
@@ -265,13 +273,15 @@ func (p Page) Backward(inJobsMode bool) Page {
 	case JobTasksPage:
 		return JobsPage
 	case ExecPage:
-		return returnToPage(inJobsMode)
+		return returnToTasksPage(inJobsMode)
 	case AllocSpecPage:
-		return returnToPage(inJobsMode)
+		return returnToTasksPage(inJobsMode)
 	case LogsPage:
-		return returnToPage(inJobsMode)
+		return returnToTasksPage(inJobsMode)
 	case LoglinePage:
 		return LogsPage
+	case StatsPage:
+		return returnToTasksPage(inJobsMode)
 	}
 	return p
 }
@@ -323,6 +333,8 @@ func (p Page) GetFilterPrefix(namespace, jobID, taskName, allocName, allocID str
 		return fmt.Sprintf("Logs for Task %s", taskFilterPrefix(taskName, allocName))
 	case LoglinePage:
 		return fmt.Sprintf("Log Line for Task %s", taskFilterPrefix(taskName, allocName))
+	case StatsPage:
+		return fmt.Sprintf("Stats for Allocation %s", allocName)
 	default:
 		panic("page not found")
 	}
@@ -385,6 +397,12 @@ func GetPageKeyHelp(
 		changeKeyHelp(&keymap.KeyMap.Compact, "compact")
 	}
 
+	if filterFocused || enteringInput {
+		keymap.KeyMap.Exit.SetHelp("ctrl+c", "exit")
+	} else {
+		keymap.KeyMap.Exit.SetHelp("q/ctrl+c", "exit")
+	}
+
 	firstRow := []key.Binding{keymap.KeyMap.Exit}
 
 	if !saving && !filterFocused {
@@ -435,6 +453,7 @@ func GetPageKeyHelp(
 
 	if currentPage.ShowsTasks() {
 		fourthRow = append(fourthRow, keymap.KeyMap.AllocEvents)
+		fourthRow = append(fourthRow, keymap.KeyMap.Stats)
 		fourthRow = append(fourthRow, keymap.KeyMap.Exec)
 	}
 
@@ -446,8 +465,7 @@ func GetPageKeyHelp(
 		}
 		if inPty {
 			changeKeyHelp(&keymap.KeyMap.Back, "disable input")
-			secondRow = []key.Binding{keymap.KeyMap.Back}
-			return getShortHelp(firstRow) + "\n" + getShortHelp(secondRow)
+			return getShortHelp([]key.Binding{keymap.KeyMap.Back})
 		} else {
 			if webSocketConnected {
 				changeKeyHelp(&keymap.KeyMap.Forward, "enable input")
